==> ejc-probuilddiary-impl-3.0.0-20220916.063711-4-sources.jar: com/ejianc/business/probuilddiary/person/bean/PersonQualityEntity.java <==
package com.ejianc.business.probuilddiary.person.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 个人日志-工程质量检查、验收情况（质检员）
 * 
 * @author generator
 * 
 */
 @TableName("ejc_probuilddiary_person_quality")
public class PersonQualityEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="person_id")
    private Long personId; // 个人日志id
    @TableField(value="quality_id")
    private Long qualityId; // 工作类别id
    @TableField(value="quality_name")
    private String qualityName; // 工作类别名称
    @TableField(value="quality_code")
    private String qualityCode; // 工作类别编码
    @TableField(value="quality_memo")
    private String qualityMemo; // 工作描述
    
    
    

    public Long getPersonId() {
        return personId;
    }

    public void setPersonId(Long personId) {
        this.personId = personId;
    }
    public Long getQualityId() {
        return qualityId;
    }

    public void setQualityId(Long qualityId) {
        this.qualityId = qualityId;
    }
    public String getQualityName() {
        return qualityName;
    }

    public void setQualityName(String qualityName) {
        this.qualityName = qualityName;
    }
    public String getQualityCode() {
        return qualityCode;
    }

    public void setQualityCode(String qualityCode) {
        this.qualityCode = qualityCode;
    }
    public String getQualityMemo() {
        return qualityMemo;
    }

    public void setQualityMemo(String qualityMemo) {
        this.qualityMemo = qualityMemo;
    }
    
}

==> ejc-probuilddiary-impl-3.0.0-20220919.071841-10-sources.jar: com/ejianc/business/probuilddiary/person/bean/PersonQualityEntity.java <==
package com.ejianc.business.probuilddiary.person.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 个人日志-工程质量检查、验收情况（质检员）
 * 
 * @author generator
 * 
 */
 @TableName("ejc_probuilddiary_person_quality")
public class PersonQualityEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="person_id")
    private Long personId; // 个人日志id
    @TableField(value="quality_id")
    private Long qualityId; // 工作类别id
    @TableField(value="quality_name")
    private String qualityName; // 工作类别名称
    @TableField(value="quality_code")
    private String qualityCode; // 工作类别编码
    @TableField(value="quality_memo")
    private String qualityMemo; // 工作描述
    @TableField(value = "file_type")
    private String fileType; // 文件类型


    public String getFileType() {
        return fileType;
    }

    public void setFileType(String fileType) {
        this.fileType = fileType;
    }
    
    

    public Long getPersonId() {
        return personId;
    }

    public void setPersonId(Long personId) {
        this.personId = personId;
    }
    public Long getQualityId() {
        return qualityId;
    }

    public void setQualityId(Long qualityId) {
        this.qualityId = qualityId;
    }
    public String getQualityName() {
        return qualityName;
    }

    public void setQualityName(String qualityName) {
        this.qualityName = qualityName;
    }
    public String getQualityCode() {
        return qualityCode;
    }

    public void setQualityCode(String qualityCode) {
        this.qualityCode = qualityCode;
    }
    public String getQualityMemo() {
        return qualityMemo;
    }

    public void setQualityMemo(String qualityMemo) {
        this.qualityMemo = qualityMemo;
    }
    
}
